UniversalSharePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • UniversalSharePlatform
Implementers

Constructors

UniversalSharePlatform()
Constructs a UniversalSharePlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shareGeneral({String? text, List<String>? filePaths}) Future<bool>
Triggers the system's native share sheet.
shareToEmail({required List<String> recipients, String? subject, String? body, List<String>? attachmentPaths, bool isHtml = false}) Future<bool>
Sends an email with native composers or system mail actions, supporting attachments.
shareToFacebookFeed({String? text, String? imagePath}) Future<bool>
Shares text and optional images directly to Facebook Feed.
shareToFacebookMessenger({String? text}) Future<bool>
Shares text directly to Facebook Messenger.
shareToFacebookStory({String? stickerAssetPath, String? backgroundAssetPath, String? topBackgroundColor, String? bottomBackgroundColor, required String facebookAppId, String? text}) Future<bool>
Shares background and sticker media directly to Facebook Stories.
shareToInstagramDirect({String? text, String? filePath}) Future<bool>
Shares text content and optional attachment directly to Instagram Direct Message.
shareToInstagramFeed({required String filePath}) Future<bool>
Shares a media file (image/video) directly to Instagram Feed.
shareToInstagramStory({String? stickerAssetPath, String? backgroundAssetPath, String? topBackgroundColor, String? bottomBackgroundColor, String? facebookAppId, String? text}) Future<bool>
Shares background and sticker media to Instagram Stories.
shareToSMS({required List<String> recipients, String? message}) Future<bool>
Sends an SMS directly to specified recipients.
shareToTelegram({String? text, String? filePath}) Future<bool>
Shares text content directly to Telegram.
shareToWhatsApp({String? text, String? phoneNumber, String? filePath}) Future<bool>
Shares a message or optional media directly to WhatsApp.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance UniversalSharePlatform
The default instance of UniversalSharePlatform to use.
getter/setter pair