MethodChannelUniversalShare class
An implementation of UniversalSharePlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- UniversalSharePlatform
- MethodChannelUniversalShare
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
Triggers the system's native share sheet.
override
-
Sends an email with native composers or system mail actions, supporting attachments.
override
-
Shares text and optional images directly to Facebook Feed.
override
-
Shares text directly to Facebook Messenger.
override
-
Shares background and sticker media directly to Facebook Stories.
override
-
Shares text content and optional attachment directly to Instagram Direct Message.
override
-
Shares a media file (image/video) directly to Instagram Feed.
override
-
Shares background and sticker media to Instagram Stories.
override
-
Sends an SMS directly to specified recipients.
override
-
Shares text content directly to Telegram.
override
-
Shares a message or optional media directly to WhatsApp.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited